@@ -10,7 +10,7 @@ class EasyCache:
     def __init__(self, redis):
         self.default_redis = redis
 
-    def find(self, prefix:str, *, redis=None, key_expire_time : int = 10 * 60,
+    def find(self, *, prefix : str = '', redis=None, key_expire_time : int = 10 * 60,
              key_param_index : int = 1, key_param_name : str = None, opt_param2key_func=None):
         def func_decorator(func):
             @wraps(func)
@@ -42,7 +42,7 @@ class EasyCache:
         return func_decorator
 
 
-    def delete(self, prefix:str, *, redis=None, key_param_index : int = 1,
+    def delete(self, *, prefix : str = '', redis=None, key_param_index : int = 1,
                key_param_name : str = None, opt_param2keys_func=None):
         def func_decorator(func):
             @wraps(func)
